pub struct Matrix<T = f64> where
T: Number, { /* fields omitted */ }
https://en.wikipedia.org/wiki/Singular_value_decomposition
M = U * Sigma * V^T
(u, sigma, vt)
with matrix decomposed by getrf
with matrix decomposed by getrf
with matrix decomposed by getrf
$$
\mathbf{A} \mathbf{x} = \mathbf{b}
$$
$$
\mathbf{x} = \mathbf{A}^{-1} \mathbf{b}
$$
with matrix decomposed by getrf
$$
\mathbf{A} \mathbf{x} = \mathbf{b}
$$
$$
\mathbf{x} = \mathbf{A}^{-1} \mathbf{b}
$$
for positiveDefinite matrix
for positive definite f64 matrix
https://en.wikipedia.org/wiki/Cholesky_decomposition
A = L * L^T
for positive definite c64 matrix
https://en.wikipedia.org/wiki/Cholesky_decomposition
A = L * L^*
with matrix decomposed by potrf
with matrix decomposed by potrf
with matrix decomposed by potrf
$$
\mathbf{A} \mathbf{x} = \mathbf{b}
$$
$$
\mathbf{x} = \mathbf{A}^{-1} \mathbf{b}
$$
with matrix decomposed by potrf
$$
\mathbf{A} \mathbf{x} = \mathbf{b}
$$
$$
\mathbf{x} = \mathbf{A}^{-1} \mathbf{b}
$$
for symmetric matrix
only k iteration
for triangle matrix
To apply this method to none triangle matrix, use LU decomposition or Cholesky decomposition.
The resulting type after applying the + operator.
The resulting type after applying the + operator.
The resulting type after applying the + operator.
The resulting type after applying the + operator.
The resulting type after applying the + operator.
The resulting type after applying the + operator.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Returns the “default value” for a type. Read more
The returned type after indexing.
Performs the indexing (container[index]) operation. Read more
The returned type after indexing.
Performs the indexing (container[index]) operation. Read more
Performs the mutable indexing (container[index]) operation. Read more
Performs the mutable indexing (container[index]) operation. Read more
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
The resulting type after applying the * operator.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
The resulting type after applying the - operator.
The resulting type after applying the - operator.
The resulting type after applying the - operator.
The resulting type after applying the - operator.
The resulting type after applying the - operator.
The resulting type after applying the - operator.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.